@@ -1014,6 +1014,8 @@ setup_input_stream (GFile *file, FileHandle *fh)
   return result;
 }
 
+#define _g_file_edit(file, flags, cancellable, error) g_file_append_to(file, flags | (1 << 15), cancellable, error)
+
 static gint
 setup_output_stream (GFile *file, FileHandle *fh, int flags)
 {
@@ -1043,7 +1045,7 @@ setup_output_stream (GFile *file, FileHandle *fh, int flags)
       else if (flags & O_APPEND)
         fh->stream = g_file_append_to (file, 0, NULL, &error);
       else
-        result = -ENOTSUP;
+        fh->stream = _g_file_edit (file, 0, NULL, &error);
       if (fh->stream)
         fh->pos = g_seekable_tell (G_SEEKABLE (fh->stream));
     }
@@ -1072,9 +1074,10 @@ open_common (const gchar *path, struct fuse_file_info *fi, GFile *file, int outp
 
   SET_FILE_HANDLE (fi, fh);
 
-  g_debug ("open_common: flags=%o (%s%s%s%s)\n",
+  g_debug ("open_common: flags=%o (%s%s%s%s%s)\n",
            fi->flags,
-           fi->flags & O_WRONLY ? "O_WRONLY " : "O_RDONLY ",
+           fi->flags & O_RDONLY ? "O_RDONLY " : "",
+           fi->flags & O_WRONLY ? "O_WRONLY " : "",
            fi->flags & O_RDWR   ? "O_RDWR "   : "",
            fi->flags & O_APPEND ? "O_APPEND " : "",
            fi->flags & O_TRUNC  ? "O_TRUNC "  : "");
@@ -1482,12 +1485,6 @@ vfs_write (const gchar *path, const gchar *buf, size_t len, off_t offset,
   gint   result = 0;
 
   g_debug ("vfs_write: %s\n", path);
-  g_debug ("vfs_write: flags=%o (%s%s%s%s)\n",
-           fi->flags,
-           fi->flags & O_WRONLY ? "O_WRONLY " : "O_RDONLY ",
-           fi->flags & O_RDWR   ? "O_RDWR "   : "",
-           fi->flags & O_APPEND ? "O_APPEND " : "",
-           fi->flags & O_TRUNC  ? "O_TRUNC "  : "");
 
   if ((file = file_from_full_path (path)))
     {
