@@ -107,7 +107,7 @@ on_autorun_loaded (GObject      *source_object,
        * has a comma at the end
        **/
       icon_regex = g_regex_new ("icon\\s*=\\s*+([^,\\r\\n]+)",
-                                G_REGEX_CASELESS, 0, NULL);
+                                G_REGEX_CASELESS | G_REGEX_RAW, 0, NULL);
       g_regex_match (icon_regex, content, 0,
                      &match_info);
 
@@ -640,7 +640,7 @@ _g_find_file_insensitive_async (GFile              *parent,
                            G_FILE_QUERY_INFO_NONE, G_PRIORITY_DEFAULT,
                            cancellable,
                            find_file_insensitive_exists_callback, task);
-
+  g_object_unref (direct_file);
 
 }
 
