@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General
  * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Alexander Larsson <alexl@redhat.com>
  */
@@ -58,9 +58,12 @@ struct _GVfsJobUnmountClass
 
 GType g_vfs_job_unmount_get_type (void) G_GNUC_CONST;
 
-GVfsJob *g_vfs_job_unmount_new (DBusConnection *connection,
-				DBusMessage *request,
-				GVfsBackend *backend);
+gboolean g_vfs_job_unmount_new_handle (GVfsDBusMount         *object,
+                                       GDBusMethodInvocation *invocation,
+                                       const gchar           *arg_dbus_id,
+                                       const gchar           *arg_obj_path,
+                                       guint                  arg_flags,
+                                       GVfsBackend           *backend);
 
 G_END_DECLS
 
